ignored_word_in_tags = {
    "about",
    "apprenants",
    "available",
    "cette",
    "command",
    "créé",
    "créée",
    "default",
    "des",
    "different",
    "directory",
    "elles",
    "est",
    "était",
    "example",
    "exemple",
    "first",
    "following",
    "for",
    "from",
    "how",
    "however",
    "http",
    "https",
    "ils",
    "import",
    "included",
    "information",
    "jusqu",
    "learn",
    "les",
    "name",
    "named",
    "never",
    "note",
    "other",
    "petit",
    "project",
    "readme",
    "should",
    "section",
    "source",
    "specify",
    "super",
    "sur",
    "system",
    "that",
    "the",
    "there",
    "these",
    "this",
    "un",
    "une",
    "use",
    "using",
    "version",
    "vous",
    "which",
    "with",
    "you",
    "your",
}